#ifndef NT2_INCLUDE_FUNCTIONS_COMPAR_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_COMPAR_HPP_INCLUDED

#include <nt2/gallery/include/functions/compar.hpp>

#endif
